{% extends "apps/base.html" %}
{% load staticfiles %}

{% block extra_css %}
{{ block.super }}
<link rel="stylesheet" href="{% static "css/abyss.widget.css" %}">
<link rel="stylesheet" href="{% static "css/detail.css" %}">
{% endblock %}

{% block navbar %}
    {% include "apps/navbar.html" with active="metrics" %}
{% endblock %}

{% block app-content %}
	<div class="row metrics-container">
		<div class="col-md-12">
				<div class="content">
						<div class="row">
							<div class="col-md-12" id="metrics-container">
							</div>
						</div>
				</div>
		</div>
	</div>
{% endblock %}

{% block extra_js %}
<script src="{% static "js/metrics.js" %}"></script>
{% endblock %}
